<?php

namespace App\Http\Controllers\Report;

use App\AccountMaster;
use App\AccountMastersAccountsDetail;
use App\Currency;
use App\SaleInvoice;
use App\SalesReturnVoucher;
use App\Http\Controllers\Controller;
use App\Services\Utils;
use Illuminate\Http\Request;
use PDF;
use Auth;

class SalesmanReportController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $user = Auth::user();
        if (!$user->can('salesmen-report')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = Utils::getLocation();
        $from_date = $request->from_date;
        $to_date = $request->to_date;

        $decimal = 0;

        $currency = Currency::Where('location_id', $location_id)->first();
        if ($currency) {
            $decimal = $currency->decimal_currency;
        }

        $salesman_id = $request->salesman_id;
        $sales_invoices = SaleInvoice::Where('salesman_id', $salesman_id)->Where('date', '>=' , $from_date)->Where('date', '<=' , $to_date)->get();
        $sales_return_vouchers = SalesReturnVoucher::Where('salesman_id', $salesman_id)->Where('date', '>=' , $from_date)->Where('date', '<=' , $to_date)->get();
        $salesman = AccountMaster::where('id', $salesman_id)->Where('location_id', $location_id)->first();
        return view('user.reports.salesman_report.index', compact('salesman','from_date','to_date','sales_invoices', 'sales_return_vouchers','decimal'));
    }

    public function display()
    {
        $user = Auth::user();
        if (!$user->can('salesmen-report')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = Utils::getLocation();
        $salesmen = AccountMaster::where('job_designation', 'salesman')->Where('location_id', $location_id)->get();
        return view('user.reports.salesman_report.select_date', compact('salesmen'));
    }

    public function pdfView($from_date, $to_date, $id){

        $user = Auth::user();
        if (!$user->can('salesmen-report')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = Utils::getLocation();

        $decimal = 0;

        $currency = Currency::Where('location_id', $location_id)->first();
        if ($currency) {
            $decimal = $currency->decimal_currency;
        }

        $salesman_id = $id;
        $sales_invoices = SaleInvoice::Where('salesman_id', $salesman_id)->Where('date', '>=' , $from_date)->Where('date', '<=' , $to_date)->get();
        $sales_return_vouchers = SalesReturnVoucher::Where('salesman_id', $salesman_id)->Where('date', '>=' , $from_date)->Where('date', '<=' , $to_date)->get();
        $salesman = AccountMaster::where('id', $salesman_id)->Where('location_id', $location_id)->first();

        // return view('user.reports.salesman_report.index', compact('salesman','from_date','to_date','sales_invoices', 'sales_return_vouchers'));
        $pdf = PDF::loadView('user.reports.salesman_report.list', compact('decimal','salesman','from_date','to_date','sales_invoices', 'sales_return_vouchers'));
        return $pdf->stream();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
