<?php

namespace App\Http\Controllers;

use App\Branches;
use App\ClassOfAccount;
use App\Country;
use App\Customer;
use App\Http\Requests\StoreCustomerRequest;
use App\Http\Requests\UpdateCustomerRequest;
use Illuminate\Support\Facades\Storage;

class CustomerMasterController extends Controller
{
    public function index()
    {
        if (!empty(($branchId = session()->get('selected_branch'))) && !Branches::hasBranchPermission($branchId, 'customers-account-master')) return response()->json(['status' => false, 'error' => 'Unauthorized'], 403);
        $customers = Customer::where('branch_id', session()->get('selected_branch'))->get();
        return view('crusher.customer_master.index', compact('customers'));
    }

    public function create()
    {
        if (!empty(($branchId = session()->get('selected_branch'))) && !Branches::hasBranchPermission($branchId, 'customers-account-master')) return response()->json(['status' => false, 'error' => 'Unauthorized'], 403);

        $countries = Country::all();
        $classOfAccount = ClassOfAccount::all();
        // $maintainAccount = Maintain::all();
        return view('crusher.customer_master.create', compact('countries', 'classOfAccount'));
    }

    public function store(StoreCustomerRequest $request)
    {
        if (!empty(($branchId = session()->get('selected_branch'))) && !Branches::hasBranchPermission($branchId, 'customers-account-master')) return response()->json(['status' => false, 'error' => 'Unauthorized'], 403);
        try {

            $validatedData = $request->validated();
            $validatedData['branch_id'] = session()->get('selected_branch');
           

            for ($i = 1; $i <= 3; $i++) {
                if ($request->hasFile("authorised_sign_{$i}_sign_sample")) {
                    $file = $request->file("authorised_sign_{$i}_sign_sample");
                    $fileName = time() . '_auth_sign_' . $i . '.' . $file->getClientOriginalExtension();
                    $filePath = $file->storeAs('uploads/admin/customer_master/authorised_docs/', $fileName, 'public');
                    $validatedData["authorised_sign_{$i}_sign_sample"] = $filePath;
                }
            }
    
            // Handle file uploads for documents
            for ($i = 1; $i <= 7; $i++) {
                if ($request->hasFile("doc_file_$i")) {
                    $file = $request->file("doc_file_$i");
                    $fileName = time() . '_doc_' . $i . '.' . $file->getClientOriginalExtension();
                    $filePath = $file->storeAs('uploads/admin/customer_master/docs/', $fileName, 'public');
                    $validatedData["doc_file_$i"] = $filePath;
                }
            }

        // Create a new customer record
        Customer::create($validatedData);
    
            flash()->addSuccess('Record Created');
            return redirect()->route('crusher.customers.index');
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }

    public function edit($customer)
    {
        if(!empty(($branchId = session()->get('selected_branch'))) && !Branches::hasBranchPermission($branchId, 'customers-account-master')) return response()->json(['status'=>false, 'error'=>'Unauthorized'], 403);
        $countries = Country::all();
        $classOfAccount = ClassOfAccount::all();
        $customer = Customer::findOrFail($customer);
        return view('crusher.customer_master.edit', compact('countries', 'classOfAccount', 'customer'));
    }

    public function show($customer)
    {
        if(!empty(($branchId = session()->get('selected_branch'))) && !Branches::hasBranchPermission($branchId, 'customers-account-master')) return response()->json(['status'=>false, 'error'=>'Unauthorized'], 403);
        $countries = Country::all();
        $classOfAccount = ClassOfAccount::all();
        $customer = Customer::with('country', 'classOfAccount')->findOrFail($customer);
        return view('crusher.customer_master.view', compact('countries', 'classOfAccount', 'customer'));
    }

    public function update(UpdateCustomerRequest $request, Customer $customer)
    {
        if (!empty(($branchId = session()->get('selected_branch'))) && !Branches::hasBranchPermission($branchId, 'customers-account-master')) {
            return response()->json(['status' => false, 'error' => 'Unauthorized'], 403);
        }

        try {
            $validatedData = $request->validated();
            $validatedData['branch_id'] = session()->get('selected_branch');

            // Handle file uploads for authorized signatory signature samples
            for ($i = 1; $i <= 3; $i++) {
                if ($request->hasFile("authorised_sign_{$i}_sign_sample")) {
                    $file = $request->file("authorised_sign_{$i}_sign_sample");
                    $fileName = time() . '_auth_sign_' . $i . '.' . $file->getClientOriginalExtension();
                    $filePath = $file->storeAs('uploads/admin/customer_master/authorised_docs/', $fileName, 'public');
                    $validatedData["authorised_sign_{$i}_sign_sample"] = $filePath;

                    // Delete existing file if it exists
                    if (!empty($customer["authorised_sign_{$i}_sign_sample"])) {
                        Storage::disk('public')->delete($customer["authorised_sign_{$i}_sign_sample"]);
                    }
                }
            }

            // Handle file uploads for documents
            for ($i = 1; $i <= 7; $i++) {
                if ($request->hasFile("doc_file_$i")) {
                    $file = $request->file("doc_file_$i");
                    $fileName = time() . '_doc_' . $i . '.' . $file->getClientOriginalExtension();
                    $filePath = $file->storeAs('uploads/admin/customer_master/docs/', $fileName, 'public');
                    $validatedData["doc_file_$i"] = $filePath;

                    // Delete existing file if it exists
                    if (!empty($customer["doc_file_$i"])) {
                        Storage::disk('public')->delete($customer["doc_file_$i"]);
                    }
                }
            }

            // Update the customer record
            $customer->update($validatedData);

            flash()->addSuccess('Record Updated');
            return redirect()->route('crusher.customers.index');
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }

    public function softDelete($customer)
    {
        $customer = Customer::findOrFail($customer);
        $customer->delete();
        flash()->addSuccess('Success');
        return redirect()->route('crusher.customers.index');
    }
}
