<?php

namespace App\Http\Controllers\MainMenu;

use App\AccountMaster;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

use Auth;
use DB;
use Storage;
use Session;
use Carbon\Carbon;

use App\Services\Slug;

use App\Country;
use App\Currency;
use App\Location;
use App\LocationPermission;
use App\PurchaseInvoice;
use App\PurchaseInvoiceItem;
use App\SaleInvoice;
use App\Services\Utils;
use App\Warehouse;
use Illuminate\Support\Facades\DB as FacadesDB;

class CountryAndLocationController extends Controller
{
    protected $slug;

    public function __construct(Slug $slug)
    {
        $this->slug = $slug;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $countries = Country::all();
        $locations = Location::all();
        return view('user.main_menu.countries_and_locations.index', compact('countries', 'locations'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function createCountry(Request $request)
    {
        $country = new Country();
        $previous = Country::Where('name', $request->name)->first();
        if ($previous) {
            Session::flash('alert-danger', 'This Country Already Exists');
            return redirect()->back();
        }
        $country->name = $request->name;
        $country->slug = $this->slug->createSlug('country', $request->name);
        $country->status = 'active';
        $country->save();
        Session::flash('alert-success', 'Country added successfully');
        return redirect('/main-menu/countries-and-locations');
    }

    public function createLocation(Request $request)
    {
        $previous = Location::Where('name', $request->name)->Where('country_id', $request->country)->first();
        if ($previous) {
            Session::flash('alert-danger', 'This Location Already Exists In This Country');
            return redirect()->back();
        }
        $location = new Location();
        $location->country_id = $request->country;
        $location->name = $request->name;
        $location->slug = $this->slug->createSlug('location', $request->name);
        $location->status = 'active';
        $location->save();
        Session::flash('alert-success', 'Location added successfully');
        return redirect('/main-menu/countries-and-locations');
    }

    public function countryLocations($country_id){
        $locations = Location::where('country_id', $country_id)->get();
        if($locations) {
            return response()->json(['status' => 'success', 'data' => $locations]);
        }else {
            return response()->json(['status' => 'not-found']);
        }
    }

    public function countryLocationsSpecific($country_id){
        $location_permission = LocationPermission::where('country_id', $country_id)->Where('user_id', Auth::user()->id)->get();
        foreach ($location_permission as $permission) {
            $locations[] = Location::Where('id', $permission->location_id)->first();
        }
        if(count($locations) > 0) {
            return response()->json(['status' => 'success', 'data' => $locations]);
        }else {
            return response()->json(['status' => 'not-found']);
        }
    }

    public function locationCurrency($location_id){
        $currency = Currency::where('location_id', $location_id)->first();
        $name = $currency->currency_id;
        $id = $currency->id;
        if($currency) {
            return response()->json(['status' => 'success', 'name' => $name, 'id' => $id]);
        }else {
            return response()->json(['status' => 'not-found']);
        }
    }

    public function locationUsers($location_id, $admin_user, $id){
        $location_permission = LocationPermission::with('users')->where('location_id', $location_id)->Where('user_id', '!=', $id)->get();
        $admin = [];
        foreach ($location_permission as $permission) {
            if ($admin_user == "admin") {
                if ($permission->users->hasRole('super-admin')) {
                    $admin[] = [
                        "id" => $permission->users->id,
                        "email" => $permission->users->email
                    ];
                }
            }elseif ($admin_user == "user") {
                if ($permission->users->hasRole('user')) {
                    $admin[] = [
                        "id" => $permission->users->id,
                        "email" => $permission->users->email
                    ];
                }
            }
        }
        // dd($location_permission);

        if($location_permission) {
            return response()->json(['status' => 'success', 'data' => $admin]);
        }else {
            return response()->json(['status' => 'not-found']);
        }
    }

    public function maintain_account_purchase($account_id){
        $account_master = AccountMaster::Where('id', $account_id)->first();
        $purchase_invoices = PurchaseInvoice::Where('account_id', $account_id)->Where('remaining_amount', '>' , 0)->get();
        // dd($purchase_invoices);
        if($purchase_invoices) {
                return response()->json(['status' => 'success', 'data'  => $purchase_invoices, 'maintain_account' => $account_master->maintain_account]);
        }else{
            return response()->json(['status' => 'not-found']);
        }

    }

    public function maintain_account_purchase_new(Request $request){

        $account_master = AccountMaster::Where('id', $request->account_id)->first();
        if ($request->invoice_id_array == "") {
            $purchase_invoices = PurchaseInvoice::Where('account_id', $request->account_id)->Where('remaining_amount', '>' , 0)->get();
        }
        else{
            $purchase_invoices = PurchaseInvoice::Where('account_id', $request->account_id)->WhereNotIn('id',  $request->invoice_id_array)->Where('remaining_amount', '>' , 0)->get();
        }

        if($purchase_invoices) {
                return response()->json(['status' => 'success', 'data'  => $purchase_invoices, 'maintain_account' => $account_master->maintain_account]);
        }else{
            return response()->json(['status' => 'not-found']);
        }

    }

    public function maintain_account_sale($account_id){
        $account_master = AccountMaster::Where('id', $account_id)->first();
        $sale_invoices = SaleInvoice::Where('account_id', $account_id)->Where('remaining_amount', '>' , 0)->get();
        // dd($purchase_invoices);
        if($sale_invoices) {
                return response()->json(['status' => 'success', 'data'  => $sale_invoices]);
        }else{
            return response()->json(['status' => 'not-found']);
        }

    }

    public function maintain_account_sale_new(Request $request){
        $account_master = AccountMaster::Where('id', $request->account_id)->first();
        if ($request->invoice_id_array == "") {
            $sale_invoices = SaleInvoice::Where('account_id', $request->account_id)->Where('remaining_amount', '>' , 0)->get();
        }
        else{
            $sale_invoices = SaleInvoice::Where('account_id', $request->account_id)->WhereNotIn('id',  $request->invoice_id_array)->Where('remaining_amount', '>' , 0)->get();
        }
        if($sale_invoices) {
                return response()->json(['status' => 'success', 'data'  => $sale_invoices, 'maintain_account' => $account_master->maintain_account]);
        }else{
            return response()->json(['status' => 'not-found']);
        }

    }

    public function amount_purchase($id){
        // $inv = [$invoice_id];
        // foreach ($request->invoice as $inv) {
            $invoice = PurchaseInvoice::Where('id', $id)->first();
        // }
        // $total_amount =  array_sum ( $sum );
        // dd($invoice->net_total);
        return response()->json(['status' => 'success', 'data'  => $invoice->remaining_amount, 'id' => $invoice->id]);
    }

    public function amount_sale($id){
        // $inv = [$invoice_id];
        // foreach ($request->invoice as $inv) {
            $invoice = SaleInvoice::Where('id', $id)->first();
        // }
        // $total_amount =  array_sum ( $sum );
        // dd($invoice->net_total);
        return response()->json(['status' => 'success', 'data'  => $invoice->remaining_amount, 'id' => $invoice->id]);
    }

    public function warehouseItem($id){
        $warehouse = Warehouse::with('items')->Where('id',$id)->first();
        $items = [];
        $location_id = $warehouse->location_id;

        foreach ($warehouse->items as $key => $item) {
            $items[] = $item->imei_serial_no;
        }
        $count = count($items);
        if ($count > 0) {
            return response()->json(['status' => 'success', 'data'  => $items]);
        }else{
            return response()->json(['status' => 'not-found']);
        }

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit_country($id)
    {
        $country = Country::Find($id);
        return view('user.main_menu.countries_and_locations.edit_country', compact('country'));
    }

    public function edit_location($id)
    {
        $location = Location::Find($id);
        return view('user.main_menu.countries_and_locations.edit_location', compact('location'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update_country(Request $request, $id)
    {
        $country = Country::Find($id);
        $previous_name = $country->name;
        if ($previous_name != $request->name) {
            $previous = Country::Where('name', $request->name)->first();
            if ($previous) {
            Session::flash('alert-danger', 'This Country '. $request->name . ' Already Exists');
            return redirect()->back();
            }
            else
                $country->name = $request->name;
                $country->slug = $this->slug->createSlug('country', $request->name);
                $country->save();

                Session::flash('alert-success', 'Country updated successfully');
                return redirect('/main-menu/countries-and-locations');
        }else
            $country->name = $request->name;
            $country->slug = $this->slug->createSlug('country', $request->name);
            $country->save();

            Session::flash('alert-success', 'Country updated successfully');
            return redirect('/main-menu/countries-and-locations');
    }

    public function update_location(Request $request, $id)
    {
        $location = Location::Find($id);
        $previous_name = $location->name;
        if ($previous_name != $request->name) {
            $previous = Location::Where('name', $request->name)->first();
            if ($previous) {
            Session::flash('alert-danger', 'This location '. $request->name . ' Already Exists');
            return redirect()->back();
            }
            else
                $location->name = $request->name;
                $location->slug = $this->slug->createSlug('location', $request->name);
                $location->save();

                Session::flash('alert-success', 'Location updated successfully');
                return redirect('/main-menu/countries-and-locations');
        }else
            $location->name = $request->name;
            $location->slug = $this->slug->createSlug('location', $request->name);
            $location->save();

            Session::flash('alert-success', 'Location updated successfully');
            return redirect('/main-menu/countries-and-locations');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy_country($id)
    {
        $country = Country::findOrFail($id);
        $location = Location::Where('country_id', $country->id)->first();
        if ($location) {
            Session::flash('alert-danger', 'This Country Has Location '. $location->name .'');
            return redirect()->back();
        }
        $country->delete();
        Session::flash('alert-success', 'Country deleted successfully');
        return redirect('/main-menu/countries-and-locations');
    }

    public function destroy_location($id)
    {
        $location = Location::findOrFail($id);
        $account_masters = AccountMaster::where('location_id', $id)->get();
        if(count($account_masters) > 0){
            Session::flash('alert-danger', 'Unable to delete location, it has data.');
            return redirect()->back();
        }
        $location->delete();
        Session::flash('alert-success', 'Location deleted successfully');
        return redirect('/main-menu/countries-and-locations');
    }

    public function randstr($len=5, $abc="aAbBcCdDeEfFgGhHiIjJkKlLmMnNoOpPqQrRsStTuUvVwWxXyYzZ")
    {
        $letters = str_split($abc);
        $str = "";
        for ($i=0; $i<=$len; $i++) {
            $str .= $letters[rand(0, count($letters)-1)];
        };
        return $str;
    }
}
