<?php

namespace App\Http\Controllers\Master;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

use Auth;
use DB;
use Storage;
use Session;
use Carbon\Carbon;
use App\Services\Utils;
use App\Services\Slug;
use App\ItemName;
use App\ItemGroup;
use App\ItemUnit;

class ItemNameController extends Controller
{

    protected $utils;
    protected $slug;

    public function __construct(Utils $utils, Slug $slug)
    {
        $this->utils = $utils;
        $this->slug = $slug;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $user = Auth::user();
        if (!$user->can('item-name-master')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $item_names = ItemName::with('groups')->with('units')->Where('location_id', $location_id)->orderBy('created_at','DESC')->paginate(100);
        return view('user.masters.item_names.index', compact('item_names'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $user = Auth::user();
        if (!$user->can('item-name-master')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $item_groups = ItemGroup::Where('location_id', $location_id)->get();
        $item_units = ItemUnit::Where('location_id', $location_id)->get();
        return view('user.masters.item_names.create', compact('item_groups','item_units'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $location_id = $this->getLocationId();

        foreach ($request->name as $key => $name) {
            $item = ItemName::Where('name', $request->name[$key])->where('location_id', $location_id)->first();
            if ($item) {
                Session::flash('alert-danger', '' .$request->name[$key]. ' Item Name Already Exists');
                return redirect('/masters/item-names');
            }else
                $item_name = new ItemName();
                $item_name->location_id = $location_id;
                $item_name->group_id = $request->group_id;
                $item_name->name = $request->name[$key];
                $item_name->unit_id = $request->unit_id[$key];
                $item_name->slug = $this->slug->createSlug('item_name', $request->name[$key]);
                $item_name->status = 'active';
                // $item_name->stock_availability =  $request->stock_availability[$key];
                $item_name->save();
        }


        Session::flash('alert-success', 'Item Name created successfully');
        return redirect('/masters/item-names');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\ItemName  $item_name
     * @return \Illuminate\Http\Response
     */
    public function show(ItemName $item_name)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\ItemName  $item_name
     * @return \Illuminate\Http\Response
     */
    public function edit($item_name_id)
    {
        $user = Auth::user();
        if (!$user->can('item-name-master')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $item_groups = ItemGroup::Where('location_id', $location_id)->get();
        $item_units = ItemUnit::Where('location_id', $location_id)->get();
        $item_name = ItemName::find($item_name_id);
        return view('user.masters.item_names.edit', compact('item_name', 'item_groups', 'item_units'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\ItemName  $item_name
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $item_name_id)
    {
        $location_id = $this->getLocationId();
        $item_name = ItemName::find($item_name_id);
        $previous_name = $item_name->name;
        if ($previous_name != $request->name) {
            $item = ItemName::Where('name', $request->name)->where('location_id', $location_id)->first();
            if ($item) {
                Session::flash('alert-danger', '' .$request->name. ' Item Name Already Exists');
                return redirect('/masters/item-names');
            }
            $item_name->group_id = $request->group_id;
            $item_name->unit_id = $request->unit_id;
            $item_name->name = $request->name;
            $item_name->slug = $this->slug->createSlug('item_name', $request->name);
            // $item_name->stock_availability = $request->stock_availability;
            $item_name->save();

            Session::flash('alert-success', 'Item Name updated successfully');
            return redirect('/masters/item-names');
        }
        else
        {
        $item_name->group_id = $request->group_id;
        $item_name->unit_id = $request->unit_id;
        $item_name->name = $request->name;
        $item_name->slug = $this->slug->createSlug('item_name', $request->name);
        // $item_name->stock_availability = $request->stock_availability == 1 ? 1 : 0;
        $item_name->save();
        Session::flash('alert-success', 'Item Name updated successfully');
        return redirect('/masters/item-names');
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\ItemName  $item_name
     * @return \Illuminate\Http\Response
     */
    public function destroy($item_name_id)
    {
        $item_name = ItemName::findOrFail($item_name_id);
        $item_name->delete();
        Session::flash('alert-success', 'Item Name deleted successfully');
        return redirect('/masters/item-names');
    }

    public function softdelete($item_name_id)
    {
        $item_name = ItemName::findOrFail($item_name_id);
        $item_name->forceDelete();
        Session::flash('alert-success', 'Item Name deleted successfully');
        return redirect('/masters/item-names');
    }
}
