<?php

namespace App\Http\Controllers;

use App\Branches;
use Illuminate\Http\Request;
use App\Notifications;
use App\NotificationTrack;
use App\Remainder;
use App\UserRemainder;

class RemainderController extends Controller
{
    public function index()
    {
        $reminders = Remainder::where('branch_id',session('selected_branch'))->get();
        return view('crusher.reminders.crusher-reminders', compact('reminders'));
    }

    function branches()
    {
        try {
            $branches = Branches::where(['country'=>request()->country, 'company_id'=>auth()->user()->company->id])->get();
            return ['status'=>true, 'data'=>$branches];
        } catch (\Throwable $th) {
            return ['status'=>false, 'data'=>$th->getMessage()];
        }
    }

    public function create()
    {
        $branches = Branches::whereHas('company', function($q){$q->where('user_id', auth()->id());})->get();
        return view('crusher.reminders.crusher-add-reminders', compact('branches'));
    }

    function store(Request $request)
    {
        try {
            $validatedData = $request->validate([
                'title' => 'nullable|string',
                'description' => 'nullable|string',
            ]);
            $validatedData['branch_id'] = session()->get('selected_branch');
            if (request()->sendToAll) {
                $reminder =  Remainder::create($validatedData);
               foreach (auth()->user()->users as $user) {
                   UserRemainder::create(['remainder_id'=>$reminder->id, 'user_id'=>$user->id]);
               }
               flash()->addSuccess('Sent');
               return redirect()->route('crusher.reminders.index');
            }
            if (request()->sendToBranch) {
                $reminder =  Remainder::create($validatedData);
                foreach (request()->users as $user) {
                    UserRemainder::create(['remainder_id'=>$reminder->id, 'user_id'=>$user]);
                }
                flash()->addSuccess('Sent');
                return redirect()->route('crusher.reminders.index');
            }
            flash()->addError('No option selected');
            return back();
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }

    public function show()
    {
        $reminder = Remainder::find(request()->reminder);
        return view('crusher.reminders.crusher-show-reminders', compact('reminder'));
    }

    public function softDelete($reminder)
    {
        $reminder = Remainder::findOrFail($reminder);
        $reminder->delete();
        flash()->addSuccess('Success');
        return back();
    }

    function updateViewed()
    {
        return UserRemainder::where('user_id',auth()->id())->update(['is_viewed'=>1]);
    }
}
