<?php

namespace App\Http\Controllers\Report;

use App\AccountMaster;
use PDF;
use Auth;

use App\AccountMasterTrack;
use App\ApprovalVoucher;
use App\Currency;
use App\Http\Controllers\Controller;
use App\ItemName;
use App\PurchaseInvoice;
use App\PurchaseSalesTransferStockTrack;
use App\SaleInvoice;
use App\Services\Utils;
use App\StaffAndSalesman;
use App\TermsAndConditionsSalesInvoice;
use App\WareHouseTrack;
use Illuminate\Http\Request;

class ApprovalReportController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $user = Auth::user();
        if (!$user->can('approval-voucher-and-do-report')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = Utils::getLocation();
        $approval_vouchers = ApprovalVoucher::with('account', 'sales_invoice')->Where('location_id', $location_id)->get();
        return view('user.reports.approval_report.index', compact('approval_vouchers'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create($id)
    {
        $user = Auth::user();
        if (!$user->can('approval-voucher-and-do-report')) {
            abort(403, 'Unauthorized action.');
        }

        $approval_voucher = ApprovalVoucher::with('items')->where('id', $id)->first();
        $location_id = Utils::getLocation();
        $latest_invoice_vat = SaleInvoice::where('location_id', $location_id)->Where('vat_check', 1)->withTrashed()->latest()->first();
        if($latest_invoice_vat){
            $invoice_no_vat = $latest_invoice_vat-> invoice_no + 1;
        }else{
            $invoice_no_vat = 1;
        }

        $latest_invoice = SaleInvoice::where('location_id', $location_id)->Where('vat_check', 0)->withTrashed()->latest()->first();
        if($latest_invoice){
            $invoice_no = (int)$latest_invoice-> invoice_no + 1 .'A' ;

        }else{
            $invoice_no = '1A';
        }
        // $salesmen = StaffAndSalesman::where('job_designation', 'salesman')->get();
        $salesmen = AccountMaster::Where('account_master_type', 'Staff-And-Salesman')->where('job_designation', 'salesman')->get();
        $warehouses = WareHouseTrack::with(['warehouse' => function($q) use ($location_id) {
            $q->where('location_id', $location_id);}])->Where('user_id', auth()->user()->id)->get();

        $account_masters = AccountMasterTrack::with(['account_master' => function($q) use ($location_id) {
            $q->where('location_id', $location_id);}])->Where('user_id', auth()->user()->id)->get();

        $item_names = ItemName::all();
        // $items = [];
        // $purchase_invoices = PurchaseInvoice::with('items')->where('location_id', $location_id)->get();
        // foreach ($purchase_invoices as $key => $purchase_invoice) {
        //     foreach ($purchase_invoice->items as $key => $item) {
        //         $items[] = $item;
        //     }
        // }
        $account = $approval_voucher->account_id;
        $pass = AccountMaster::Find($account);

        if ($pass->transactions_password != "") {
            $pass_check = "yes";
        }elseif ($pass->transactions_password == "") {
            $pass_check = "no";
        }
        $items = PurchaseSalesTransferStockTrack::Where('location_id', $location_id)->Where('quantity', '!=', 0)->get();
        $terms_and_conditions_sales_invoice = TermsAndConditionsSalesInvoice::where('location_id', $location_id)->first();
        $currency = Currency::Where('location_id', $location_id)->first();
        return view('user.reports.approval_report.create', compact('pass_check','currency','approval_voucher','invoice_no','invoice_no_vat','account_masters', 'salesmen', 'warehouses','item_names', 'items', 'terms_and_conditions_sales_invoice'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    public function pdfView(){
        $user = Auth::user();
        if (!$user->can('approval-voucher-and-do-report')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = Utils::getLocation();
        $approval_vouchers = ApprovalVoucher::with('account', 'sales_invoice')->Where('location_id', $location_id)->get();
        $pdf = PDF::loadView('user.reports.approval_report.list', compact('approval_vouchers'));
        return $pdf->stream();
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
