<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\AccountMaster;
use App\AccountMastersAccountsDetail;
use App\ClassOfAccount;
use App\Currency;
use App\Http\Controllers\Controller;
use App\PurchaseInvoice;
use App\PurchaseReturnVoucher;
use App\SaleInvoice;
use App\SalesReturnVoucher;
use App\Services\Utils;
use Carbon\Carbon;
use PDF;
use Auth;
use App\Customer;
use App\Expense;
use App\Supplier;
use App\StaffAndSalesman;
use App\AdminOtherAccount;
use App\AdminSalesInvoice;
use App\Company;
use App\DeliveryNote;
use App\AdminTermsAndCondition;
use Illuminate\Support\Facades\DB;
class StatmentOfAccountController extends Controller
{
    public function display()
    {
        $user = Auth::user();
        // if (!$user->can('reports.statement_account')) {
        //     //     abort(403, 'Unauthorized action.');
        //     // }

        $accounts = [];

        $customers = Customer::where('branch_id', session()->get('selected_branch'))
            ->select('*', 'name_of_organisation as account_name')
            ->get()
            ->map(function ($item) {
                return $item->setAttribute('table_name', 'App\Customer');
            });

        $salesmens = StaffAndSalesman::where('branch_id', session()->get('selected_branch'))
            ->select('*', DB::raw("CONCAT(first_name, ' ', last_name) as account_name"))
            ->get()
            ->map(function ($item) {
                return $item->setAttribute('table_name', 'App\StaffAndSalesman');
            });

        $suppliers = Supplier::where('branch_id', session()->get('selected_branch'))
            ->select('*', 'name_of_organisation as account_name')
            ->get()
            ->map(function ($item) {
                return $item->setAttribute('table_name', 'App\Supplier');
            });

        $expenses = Expense::where('branch_id', session()->get('selected_branch'))
            ->get()
            ->map(function ($item) {
                return $item->setAttribute('table_name', 'App\Expense');
            });

        $otherAccounts = AdminOtherAccount::where('branch_id', session()->get('selected_branch'))
            ->get()
            ->map(function ($item) {
                return $item->setAttribute('table_name', 'App\AdminOtherAccount');
            });

        $accounts = $customers->concat($expenses)->concat($suppliers)->concat($otherAccounts)->concat($salesmens);

        $class_of_accounts = ClassOfAccount::all();

        return view('crusher.reports.statement_account', compact('accounts', 'class_of_accounts'));
    }

    public function index_class(Request $request)
    {
        $user = Auth::user();
        // if (!$user->can('statement-of-account-report')) {
        //     abort(403, 'Unauthorized action.');
        // }

        $location_id = Utils::getLocation();
        $from_date = $request->from_date;
        $to_date = $request->to_date;

        $class_of_account = ClassOfAccount::with(['account_master' => function($q) use ($location_id) {
            $q->where('location_id', $location_id);}])->where('id', $request->class_of_account)->first();

            $combinedData = DB::table('class_of_accounts')
            ->select(
                'class_of_accounts.name as classOfAccountName',
                DB::raw('SUM(COALESCE(Customers.opening_balance, 0) + COALESCE(expenses.opening_balance, 0) + COALESCE(other_accounts.opening_balance, 0) + COALESCE(suppliers.opening_balance, 0)) as totalOpeningBalance')
            )
            ->leftJoin('Customers', 'class_of_accounts.id', '=', 'Customers.class_of_account_id')
            ->leftJoin('expenses', 'class_of_accounts.id', '=', 'expenses.class_of_account_id')
            ->leftJoin('other_accounts', 'class_of_accounts.id', '=', 'other_accounts.class_of_account_id')
            ->leftJoin('suppliers', 'class_of_accounts.id', '=', 'suppliers.class_of_account_id')
            ->where(function ($query) use ($from_date, $to_date) {
                $query->whereBetween('Customers.date', [$from_date, $to_date])
                    ->orWhereBetween('expenses.date', [$from_date, $to_date])
                    ->orWhereBetween('other_accounts.date', [$from_date, $to_date])
                    ->orWhereBetween('suppliers.date', [$from_date, $to_date]);
            })
            ->groupBy('classOfAccountName')
            ->get();

        return view('crusher.reports.index_class_of_account', compact('class_of_account', 'from_date', 'to_date', 'combinedData'));
    }
    public function index_ledger_billwise(Request $request)
    {
        $user = Auth::user();
        // if (!$user->can('statement-of-account-report')) {
        //     abort(403, 'Unauthorized action.');
        // }

        // dd($request->all());
        $location_id = Utils::getLocation();
        $from_date = $request->from_date;
        $to_date = $request->to_date;
        $ledger = AccountMaster::Find($request->ledger_class);

        $decimal = 0;

        $currency = Currency::Where('location_id', $location_id)->first();
        if ($currency) {
            $decimal = $currency->decimal_currency;
        }

        $purchase_invoices = PurchaseInvoice::Where('account_id', $ledger->id)->Where('invoice_no', '!=' , '0')->Where('date', '>=' , $from_date)->Where('date', '<=' , $to_date)->get();
        foreach ($purchase_invoices as $key => $purchase_invoice) {
            $purchase_invoice-> invoice_type = 'purchase';
            $date = new Carbon($purchase_invoice->date);
            $days = $purchase_invoice->lpo_days;
            if ($days == "") {
                $due_date = $date->format('Y-m-d');
            }else{
                $due_date = $date->addDays($days)->format('Y-m-d');
            }
            $purchase_invoice->due_date = $due_date;

            if ($due_date >= Carbon::now()) {
                $diff = 0;
            }else{
                $diff = Carbon::parse(Carbon::now())->diffInDays($due_date);
            }
            $purchase_invoice->diff = $diff;
        }
        $sale_invoices = SaleInvoice::Where('account_id', $ledger->id)->Where('date', '>=' , $from_date)->Where('date', '<=' , $to_date)->get();
        foreach ($sale_invoices as $key => $sale_invoice) {
            $sale_invoice-> invoice_type = 'sales';
            $date = new Carbon($sale_invoice->date);
            $days = $sale_invoice->lpo_days;
            if ($days == "") {
                $due_date = $date->format('Y-m-d');
            }else{
                $due_date = $date->addDays($days)->format('Y-m-d');
            }
            $sale_invoice->due_date = $due_date;
            if ($due_date >= Carbon::now()) {
                $diff = 0;
            }else{
                $diff = Carbon::parse(Carbon::now())->diffInDays($due_date);
            }
            $sale_invoice->diff = $diff;
        }

        $unsorted_data  = $sale_invoices->concat($purchase_invoices);
        $collection = collect($unsorted_data);
        $sorted_data = $collection->sortBy('date')->values()->all();

        return view('crusher.reports.statement_of_accounts.index_ledger_billwise', compact('from_date','to_date','ledger','sorted_data','decimal'));
    }

    public function index_ledger_vatwise($deliveryNote)
    {
        $deliveryNote = DeliveryNote::find($deliveryNote);
        $deliveryNote = $deliveryNote->with('item', 'account', 'buyer')->where('do_no', $deliveryNote->do_no)->get();
        // dd($deliveryNote);
        $company = Company::where('user_id', auth()->id())->first();
        $tnc = AdminTermsAndCondition::where(['branch_id'=>session()->get('selected_branch'), 'type'=>'delivery_note'])->first();
        dd('deliveryNote');
        return view('crusher.reports.index_ledger_vatwise', compact('deliveryNote'));

    }
    // public function index_ledger_vatwise(Request $request, $accountId)
    // {
    //     $vatOption = $request->input('vatOption');

    //     // Fetch data based on $accountId and $vatOption
    //     // Replace 'yourData' with the actual query to fetch the data

    //     $deliveryNoteData = DeliveryNote::where('account_id', $accountId)
    //         ->where('vat_option', $vatOption)
    //         ->get();

    //     // Return the data as a JSON response
    //     return view('crusher.reports.index_ledger_vatwise', compact('deliveryNoteData'));
    // }

    public function view1()
    {
        return view('crusher.reports.statement_account_1');
    }

    public function view3()
    {
        return view('crusher.reports.statement_account_3');
    }


}
